/****************************************************************************/
/*                                                                          */
/*                      Chaine de CAO & VLSI   Alliance                     */
/*                                                                          */
/*    Produit :  NetOptim & synthese logique                                */
/*    Fichier :  generic.h                                                  */
/*                                                                          */
/*    (c) copyright 1992 Laboratoire MASI equipe CAO & VLSI                 */
/*    Tous droits reserves                                                  */
/*    Support : e-mail cao-vlsi@masi.ibp.fr                                 */
/*                                                                          */
/*    Auteur(s) : N. Dictus                             le : 03/08/1992     */
/*                                                                          */
/*    Modifie par :                                     le : ../../....     */
/*    Modifie par :                                     le : ../../....     */
/*    Modifie par :                                     le : ../../....     */
/*                                                                          */
/****************************************************************************/

	/* polarite */
#define NEG 0
#define POS 1
#define AUT 2

	/* type */
#define ERR 0
#define COMBI 1
#define REG 2
#define BUS 3
#define CONST 4
#define BUFF 5

	/* transition */
#define LL 0
#define LH 1
#define HL 2
#define HH 3

	/* resistance */
#define DOWN  0
#define UP 1


/* --------------------------------------------------------------------------*/
/*  --------- FONCTIONS calculant les generics de la structure cellule logique,               a partir du champ generic --- */
/* --------------------------------------------------------------------------*/

long searchGeneric();
long delaiIn();
num_list *findDelaisGen();
num_list *findCapaGen();
int resistance();
char *findResistanceGen();
void recupGeneric();

long getDelai();
void triExpr();
short okInterface();
chain_list *memberChain_list();
short member();
Alist *initPort();
Alist *initIn();
chain_list *initOut();
short commut();
void calculEnvel();
biabl_list *reCopyBiabl();
Alist *triOrdreInterface();
chain_list *normMappingExpr();
