/****************************************************************************/
/*                                                                          */
/*                      Chaine de CAO & VLSI   Alliance                     */
/*                                                                          */
/*    Produit : Synthetiseur logique                                        */
/*    Fichier : compile.h                                                   */
/*                                                                          */
/*    (c) copyright 1991 Laboratoire MASI equipe CAO & VLSI                 */
/*    Tous droits reserves                                                  */
/*    Support : e-mail cao-vlsi@masi.ibp.fr                                 */
/*                                                                          */
/*    Auteur(s) :   DICTUS N.                           le : 06/08/1991     */
/*                                                                          */
/*    Modifie par :                                     le : ../../....     */
/*    Modifie par :                                     le : ../../....     */
/*    Modifie par :                                     le : ../../....     */
/*                                                                          */
/****************************************************************************/

extern befig_list *VHB_HEDFIG;

short		ohInterface();
chain_list	*memberChain_list();
short 		member();
Alist		*initIn();
chain_list	*initOut();
short		commut();
void		calculEnvel();
char		*findR();
long		findS();
num_list	*findD();
biabl_list 	*reCopyBiabl();

cellList 	*initCellList();
mapping 	*initMapping();
cellList 	*endMapping();
void 		recupGeneric();
void		compileLibrary();
void 		cellLog();
long		getDelai();
void 		triExpr();
chain_list 	*ablContraint();
chain_list 	*normMappingExpr();
num_list 	*findDelaisGen();
char 		*renameSig();
